API_VERSION = "v1"
API_PATH = "https://inversionesyfinanzas.xyz/api/"


ALL_EXCHANGES = "lista-exchanges"
ALL_INDUSTRIES = "lista-industrias"
ALL_SECTORS = "lista-sectores"

ALL_COMPANIES = "lista-empresas"
SINGLE_COMPANY_FULL = "empresa-completa"
SINGLE_COMPANY_BASIC = "empresa-basica"

INCOME_STATEMENT = "estado-resultados"
BALANCE_SHEET = "balance-general"
CASHFLOW_STATEMENT = "estado-flujo-efectivo"

ALL_TERMS = "lista-terminos"
SINGLE_TERM = "termino"

ALL_SUPERINVESTORS = "lista-superinversores"
SINGLE_SUPERINVESTOR_HISTORIAL = "lista-historial"
SINGLE_SUPERINVESTOR_MOVEMENTS = "lista-movimientos"
